@@ -4,11 +4,19 @@ from .inverter import Inverter
 
 
 class BMWFile(Inverter):
-    def __init__(self, filename, decrypted_extension=None, encrypted_extension=None, encrypted=False):
+    def __init__(
+            self,
+            filename,
+            decrypted_extension=None,
+            encrypted_extension=None,
+            encrypted=False,
+            encrypt_length=None
+    ):
         self._filename = filename
         self._decrypted_extension = decrypted_extension
         self._encrypted_extension = encrypted_extension
         self._encrypted = encrypted
+        self._encrypt_length = encrypt_length
 
     def __str__(self):
         return f"{self._filename}: encrypted={self._encrypted}"
@@ -34,6 +42,6 @@ class BMWFile(Inverter):
             "wb"
         ) as destination_file:
             if self._encrypted != encrypt:
-                contents = self.invert(contents)
+                contents = self.invert(contents, self._encrypt_length)
 
             destination_file.write(contents)
